==> AsposeCellsCloud-CellsApi-25.9.tar.gz: AsposeCellsCloud-CellsApi-25.9/docs/model/Axis.md <==
# AsposeCellsCloud::Object::Axis 

## Load the model package
```perl
use AsposeCellsCloud::Object::Axis;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**Area** | **Area** | Gets the . |
**AxisBetweenCategories** | **boolean** | Represents if the value axis crosses the category axis between categories. |
**AxisLine** | **Line** | Gets the appearance of an Axis. |
**BaseUnitScale** | **string** | Represents the base unit scale for the category axis. |
**CategoryType** | **string** | Represents the category axis type. |
**CrossAt** | **double** | Represents the point on the value axis where the category axis crosses it. |
**CrossType** | **string** | Represents the  on the specified axis where the other axis crosses. |
**DisplayUnit** | **string** | Represents the unit label for the specified axis. |
**DisplayUnitLabel** | **DisplayUnitLabel** | Represents a unit label on an axis in the specified chart.                         Unit labels are useful for charting large values— for example, in the millions or billions. |
**HasMultiLevelLabels** | **boolean** | Indicates whether the labels shall be shown as multi level. |
**IsAutomaticMajorUnit** | **boolean** | Indicates whether the major unit of the axis is automatically assigned. |
**IsAutomaticMaxValue** | **boolean** | Indicates whether the max value is automatically assigned. |
**IsAutomaticMinorUnit** | **boolean** | Indicates whether the minor unit of the axis is automatically assigned. |
**IsAutomaticMinValue** | **boolean** | Indicates whether the min value is automatically assigned. |
**IsDisplayUnitLabelShown** | **boolean** | Represents if the display unit label is shown on the specified axis. |
**IsLogarithmic** | **boolean** | Represents if the value axis scale type is logarithmic or not. |
**IsPlotOrderReversed** | **boolean** | Represents if Microsoft Excel plots data points from last to first. |
**IsVisible** | **boolean** | Represents if the axis is visible. |
**LogBase** | **double** | Represents the logarithmic base. Default value is 10.Only applies for Excel2007. |
**MajorGridLines** | **Line** | Represents major gridlines on a chart axis. |
**MajorTickMark** | **string** | Represents the type of major tick mark for the specified axis. |
**MajorUnit** | **double** | Represents the major units for the axis. |
**MajorUnitScale** | **string** | Represents the major unit scale for the category axis. |
**MaxValue** | **double** | Represents the maximum value on the value axis. |
**MinorGridLines** | **Line** | Represents minor gridlines on a chart axis. |
**MinorTickMark** | **string** | Represents the type of minor tick mark for the specified axis. |
**MinorUnit** | **double** | Represents the minor units for the axis. |
**MinorUnitScale** | **string** | Represents the major unit scale for the category axis. |
**MinValue** | **double** | Represents the minimum value on the value axis. |
**TickLabelPosition** | **string** | Represents the position of tick-mark labels on the specified axis. |
**TickLabels** | **TickLabels** | Returns a  object that represents the tick-mark labels for the specified axis. |
**TickLabelSpacing** | **int** | Represents the number of categories or series between tick-mark labels. Applies only to category and series axes. |
**TickMarkSpacing** | **int** | Returns or sets the number of categories or series between tick marks. Applies only to category and series axes. |
**Title** | **Title** | Gets the axis' title. |
**link** | **Link** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/Axis.md <==
# AsposeCellsCloud::Object::Axis 

## Load the model package
```perl
use AsposeCellsCloud::Object::Axis;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**Area** | **Area** | Gets the . |
**AxisBetweenCategories** | **boolean** | Represents if the value axis crosses the category axis between categories. |
**AxisLine** | **Line** | Gets the appearance of an Axis. |
**BaseUnitScale** | **string** | Represents the base unit scale for the category axis. |
**CategoryType** | **string** | Represents the category axis type. |
**CrossAt** | **double** | Represents the point on the value axis where the category axis crosses it. |
**CrossType** | **string** | Represents the  on the specified axis where the other axis crosses. |
**DisplayUnit** | **string** | Represents the unit label for the specified axis. |
**DisplayUnitLabel** | **DisplayUnitLabel** | Represents a unit label on an axis in the specified chart.                         Unit labels are useful for charting large values— for example, in the millions or billions. |
**HasMultiLevelLabels** | **boolean** | Indicates whether the labels shall be shown as multi level. |
**IsAutomaticMajorUnit** | **boolean** | Indicates whether the major unit of the axis is automatically assigned. |
**IsAutomaticMaxValue** | **boolean** | Indicates whether the max value is automatically assigned. |
**IsAutomaticMinorUnit** | **boolean** | Indicates whether the minor unit of the axis is automatically assigned. |
**IsAutomaticMinValue** | **boolean** | Indicates whether the min value is automatically assigned. |
**IsDisplayUnitLabelShown** | **boolean** | Represents if the display unit label is shown on the specified axis. |
**IsLogarithmic** | **boolean** | Represents if the value axis scale type is logarithmic or not. |
**IsPlotOrderReversed** | **boolean** | Represents if Microsoft Excel plots data points from last to first. |
**IsVisible** | **boolean** | Represents if the axis is visible. |
**LogBase** | **double** | Represents the logarithmic base. Default value is 10.Only applies for Excel2007. |
**MajorGridLines** | **Line** | Represents major gridlines on a chart axis. |
**MajorTickMark** | **string** | Represents the type of major tick mark for the specified axis. |
**MajorUnit** | **double** | Represents the major units for the axis. |
**MajorUnitScale** | **string** | Represents the major unit scale for the category axis. |
**MaxValue** | **double** | Represents the maximum value on the value axis. |
**MinorGridLines** | **Line** | Represents minor gridlines on a chart axis. |
**MinorTickMark** | **string** | Represents the type of minor tick mark for the specified axis. |
**MinorUnit** | **double** | Represents the minor units for the axis. |
**MinorUnitScale** | **string** | Represents the major unit scale for the category axis. |
**MinValue** | **double** | Represents the minimum value on the value axis. |
**TickLabelPosition** | **string** | Represents the position of tick-mark labels on the specified axis. |
**TickLabels** | **TickLabels** | Returns a  object that represents the tick-mark labels for the specified axis. |
**TickLabelSpacing** | **int** | Represents the number of categories or series between tick-mark labels. Applies only to category and series axes. |
**TickMarkSpacing** | **int** | Returns or sets the number of categories or series between tick marks. Applies only to category and series axes. |
**Title** | **Title** | Gets the axis' title. |
**link** | **Link** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
